import utfcolor.utfcolorv2 as utfcolorv2


class UtfColorV3(utfcolorv2.UtfColorV2):
    def __init__(self):
        self.encoding = {
            "e": "00FA9A",#MediumSpringGreen
            "n": "191970",#MidnightBlue
            "i": "3CB371",#MediumSeaGreen
            "s": "0000FF",#Blue
            "r": "00008B",#DarkBlue
            "a": "32CD32",#LimeGreen
            "t": "0000CD",#MediumBlue
            "d": "4169E1",#RoyalBlue
            "h": "1E90FF",#DodgerBlue
            "u": "008000",#Green
            "l": "00BFFF",#DeepSkyBlue
            "c": "6495ED",#CornflowerBlue
            "g": "87CEEB",#SkyBlue
            "m": "87CEFA",#LightSkyBlue
            "o": "9ACD32",#YellowGreen
            "b": "B0E0E6",#PowderBlue
            "w": "B0C4DE",#LightSteelBlue
            "f": "4682B4",#SteelBlue
            "k": "5F9EA0",#CadetBlue
            "z": "00CED1",#DarkTurquoise
            "p": "7FFFD4",#Aquamarine
            "v": "AFEEEE",#PaleTurquoise
            "j": "00FFFF",#Cyan
            "y": "008080",#Teal
            "x": "20B2AA",#LightSeaGreen
            "q": "66CDAA",#MediumAquaMarine
            "1": "FF69B4",#HotPink
            "2": "C71585",#MediumVioletRed
            "3": "9400D3",#DarkViolet
            "4": "DA70D6",#Orchid
            "5": "9370DB",#MediumPurple
            "6": "6A5ACD",#SlateBlue
            "7": "663399",#RebeccaPurple
            "8": "4B0082",#Indigo
            "9": "FFB6C1",#LightPink
            "0": "DB7093",#PaleVioletRed
            ".": "000000",#Black
            ",": "A9A9A9",#DarkGray
            " ": "FFFFFF"#White
        }